Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(625)

Unified Diff: chrome/installer/util/google_update_settings.h

Issue 365133005: Refactor SetClientID such that metrics rather than crash backs up the client id in Google Update set (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: nits:grt Created 6 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/common/crash_keys.cc ('k') | chrome/installer/util/google_update_settings.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/installer/util/google_update_settings.h
diff --git a/chrome/installer/util/google_update_settings.h b/chrome/installer/util/google_update_settings.h
index b7bf6125613e9c0e492566dd3be7474fc9d01b25..a8e43c426d9ef33a0b3fcd337a72cd5f78678f25 100644
--- a/chrome/installer/util/google_update_settings.h
+++ b/chrome/installer/util/google_update_settings.h
@@ -86,12 +86,12 @@ class GoogleUpdateSettings {
bool consented);
#endif
- // Returns the metrics id set in the registry (that can be used in crash
- // reports). If none found, returns empty string.
- static bool GetMetricsId(std::string* metrics_id);
+ // Returns the metrics client id backed up in the registry. If none found,
+ // returns empty string.
+ static bool LoadMetricsClientId(std::string* metrics_id);
- // Sets the metrics id to be used in crash reports.
- static bool SetMetricsId(const std::string& metrics_id);
+ // Stores a backup of the metrics client id in the registry.
+ static bool StoreMetricsClientId(const std::string& metrics_id);
// Sets the machine-wide EULA consented flag required on OEM installs.
// Returns false if the setting could not be recorded.
« no previous file with comments | « chrome/common/crash_keys.cc ('k') | chrome/installer/util/google_update_settings.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698